Changelog
=========

Version 1.0.5

  - bug fixes for logger configuration
  - bug fixes in moke executable

Version 1.0.4
-------------

  - added support to bootstrap with config file
  - fixed moke binary to handle script, config, and args

Version 1.0.3
-------------
  
  - added support for config file with global options
  - fixed moke binary to properly create new mokefile 

Version 1.0.2
-------------

  - fixed 'moke' script option parsing


Version 1.0.1
-------------

  - support for 'moke new'
  - added error when mokefile contains no functions
  

Version 1.0.0
-------------

  - Initial commit
